==> qt-creator-2.2.1-src.zip: qt-creator-2.2.1-src/src/plugins/projectexplorer/sessionnodeimpl.cpp <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#include "sessionnodeimpl.h"
#include "session.h"

namespace ProjectExplorer {
namespace Internal {

SessionNodeImpl::SessionNodeImpl(SessionManager *manager)
        : ProjectExplorer::SessionNode(manager->currentSession(), manager)
{
    setFileName(QLatin1String("session"));
}

void SessionNodeImpl::addProjectNode(ProjectNode *projectNode)
{
    addProjectNodes(QList<ProjectNode*>() << projectNode);
}

void SessionNodeImpl::removeProjectNode(ProjectNode *projectNode)
{
    removeProjectNodes(QList<ProjectNode*>() << projectNode);
}

void SessionNodeImpl::setFileName(const QString &fileName)
{
    setPath(fileName);
    setDisplayName(fileName);
}

} // namespace Internal
} // namespace ProjectExplorer

==> qt-creator-2.3.1-src.zip: qt-creator-2.3.1-src/src/plugins/projectexplorer/sessionnodeimpl.cpp <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (info@qt.nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at info@qt.nokia.com.
**
**************************************************************************/

#include "sessionnodeimpl.h"
#include "session.h"

namespace ProjectExplorer {
namespace Internal {

SessionNodeImpl::SessionNodeImpl(SessionManager *manager)
        : ProjectExplorer::SessionNode(
              manager->sessionNameToFileName(manager->currentSession()),
              manager)
{
    setFileName(QLatin1String("session"));
}

void SessionNodeImpl::addProjectNode(ProjectNode *projectNode)
{
    addProjectNodes(QList<ProjectNode*>() << projectNode);
}

void SessionNodeImpl::removeProjectNode(ProjectNode *projectNode)
{
    removeProjectNodes(QList<ProjectNode*>() << projectNode);
}

void SessionNodeImpl::setFileName(const QString &fileName)
{
    setPath(fileName);
    setDisplayName(fileName);
}

} // namespace Internal
} // namespace ProjectExplorer
